yazi_macro::mod_flat!(
	bulk_rename
	close
	create
	hardlink
	link
	open
	paste
	peek
	quit
	refresh
	remove
	rename
	seek
	spot
	suspend
	tab_close
	tab_create
	tab_swap
	tab_switch
	unyank
	update_files
	update_mimes
	update_paged
	update_tasks
	update_yanked
	watch
	yank
);
